NodeType

Enum NodeType 

pub enum NodeType {
Show 44 variants Document, Paragraph, SimpleLine, EmptyLine, Section, PlainText, PlainTextSpecialChars, PlainTextEmphasis, ShortBreak, Break, ShortEmphasisModerate, ShortEmphasisStrong, ShortEmphasisNone, ShortEmphasisReduced, TextModifier, ShortIpa, BareIpa, ShortSub, Audio, Mark, Emphasis, Voice, Lang, Rate, Pitch, Volume, Whisper, Excited, Disappointed, Newscaster, Dj, Date, Time, Number, Ordinal, Characters, Fraction, Telephone, Unit, Address, Interjection, Expletive, Ipa, Sub,
}
Types of AST nodes in SpeechMarkdown

Variants



Document

Root document node



Paragraph

Paragraph node



SimpleLine

Simple line (no modifiers)



EmptyLine

Empty line



Section

Section with modifiers



PlainText

Plain text content



PlainTextSpecialChars

Text with special characters



PlainTextEmphasis

Text in emphasis context



ShortBreak

Short break notation [time]



Break

Extended break with strength



ShortEmphasisModerate

Moderate emphasis +text+



ShortEmphasisStrong

Strong emphasis ++text++



ShortEmphasisNone

No emphasis text



ShortEmphasisReduced

Reduced emphasis -text-



TextModifier

Text modifier (text)[key:value]



ShortIpa

Short IPA notation (/text/phoneme/)



BareIpa

Bare IPA notation /phoneme/



ShortSub

Short substitution {text}alias



Audio

Audio element caption



Mark

Mark tag



Emphasis

Emphasis modifier



Voice

Voice modifier



Lang

Language modifier



Rate

Rate modifier



Pitch

Pitch modifier



Volume

Volume modifier



Whisper

Whisper modifier



Excited

Excited modifier



Disappointed

Disappointed modifier



Newscaster

Newscaster modifier



Dj

DJ modifier



Date

Date modifier



Time

Time modifier



Number

Number modifier



Ordinal

Ordinal modifier



Characters

Characters modifier



Fraction

Fraction modifier



Telephone

Telephone modifier



Unit

Unit modifier



Address

Address modifier



Interjection

Interjection modifier



Expletive

Expletive/Bleep modifier



Ipa

IPA modifier



Sub

Substitution modifier

Implementations

Source

impl NodeType

pub fn is_emphasis(&self) -> bool

Check if this node type represents emphasis

pub fn is_break(&self) -> bool

Check if this node type represents a break/pause

pub fn is_modifier(&self) -> bool

Check if this node type represents a modifier